==> open-cluster-management-search-model-6.3.1-sources.jar: io/fabric8/openclustermanagement/api/model/searchoperator/v1alpha1/SearchOperatorStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SearchOperatorStatusFluentImpl<A extends SearchOperatorStatusFluent<A>> extends BaseFluent<A> implements SearchOperatorStatusFluent<A>{
  public SearchOperatorStatusFluentImpl() {
  }
  public SearchOperatorStatusFluentImpl(SearchOperatorStatus instance) {
    this.withDeployredisgraph(instance.getDeployredisgraph()); 
    this.withPersistence(instance.getPersistence()); 
  }
  private Boolean deployredisgraph;
  private String persistence;
  public Boolean getDeployredisgraph() {
    return this.deployredisgraph;
  }
  public A withDeployredisgraph(Boolean deployredisgraph) {
    this.deployredisgraph=deployredisgraph; return (A) this;
  }
  public Boolean hasDeployredisgraph() {
    return this.deployredisgraph != null;
  }
  public String getPersistence() {
    return this.persistence;
  }
  public A withPersistence(String persistence) {
    this.persistence=persistence; return (A) this;
  }
  public Boolean hasPersistence() {
    return this.persistence != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SearchOperatorStatusFluentImpl that = (SearchOperatorStatusFluentImpl) o;
    if (deployredisgraph != null ? !deployredisgraph.equals(that.deployredisgraph) :that.deployredisgraph != null) return false;
    if (persistence != null ? !persistence.equals(that.persistence) :that.persistence != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(deployredisgraph,  persistence,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (deployredisgraph != null) { sb.append("deployredisgraph:"); sb.append(deployredisgraph + ","); }
    if (persistence != null) { sb.append("persistence:"); sb.append(persistence); }
    sb.append("}");
    return sb.toString();
  }
  public A withDeployredisgraph() {
    return withDeployredisgraph(true);
  }
  
}

==> open-cluster-management-search-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/searchoperator/v1alpha1/SearchOperatorStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SearchOperatorStatusFluentImpl<A extends SearchOperatorStatusFluent<A>> extends BaseFluent<A> implements SearchOperatorStatusFluent<A>{
  public SearchOperatorStatusFluentImpl() {
  }
  public SearchOperatorStatusFluentImpl(SearchOperatorStatus instance) {
    if (instance != null) {
      this.withDeployredisgraph(instance.getDeployredisgraph());
      this.withPersistence(instance.getPersistence());
    }
  }
  private Boolean deployredisgraph;
  private String persistence;
  public Boolean getDeployredisgraph() {
    return this.deployredisgraph;
  }
  public A withDeployredisgraph(Boolean deployredisgraph) {
    this.deployredisgraph=deployredisgraph; return (A) this;
  }
  public Boolean hasDeployredisgraph() {
    return this.deployredisgraph != null;
  }
  public String getPersistence() {
    return this.persistence;
  }
  public A withPersistence(String persistence) {
    this.persistence=persistence; return (A) this;
  }
  public Boolean hasPersistence() {
    return this.persistence != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SearchOperatorStatusFluentImpl that = (SearchOperatorStatusFluentImpl) o;
    if (!java.util.Objects.equals(deployredisgraph, that.deployredisgraph)) return false;

    if (!java.util.Objects.equals(persistence, that.persistence)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(deployredisgraph,  persistence,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (deployredisgraph != null) { sb.append("deployredisgraph:"); sb.append(deployredisgraph + ","); }
    if (persistence != null) { sb.append("persistence:"); sb.append(persistence); }
    sb.append("}");
    return sb.toString();
  }
  public A withDeployredisgraph() {
    return withDeployredisgraph(true);
  }
  
}
